ValidationIssue class

Represents an issue found during validation

Constructors

ValidationIssue({required IssueType type, required String message, required String file, bool fixable = false})
const

Properties

file String
final
fixable bool
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type IssueType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited