ValidateCommand class
Command to validate existing packages
Constructors
Properties
- argParser → ArgParser
-
Parser de argumentos para este comando
no setteroverride
- description → String
-
Descripción del comando
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Nombre del comando
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
ArgResults argResults) → Future< void> -
Ejecuta el comando con los argumentos parseados
override
-
showHelp(
) → void -
Muestra ayuda específica del comando
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited