ValidationIssue class
Represents an issue found during validation
Constructors
- ValidationIssue({required IssueType type, required String message, required String file, bool fixable = false})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited